from setuptools import setup, find_packages

setup(
    name="pyloch",
    version="0.1.0",
    description="هذا المكتبه تحت اشراف حسو ال علي وتحت التطوير حاليا سيتم اضافه تحديثات جديده كل يوم",
    author="Hasneen Qusay",
    author_email="lyhasneen70@gmail.com",
    license="MIT",
    packages=find_packages(),
    python_requires=">=3.7",
)
